/**
 * Copyright (c) 2025 Dominic Masters
 * 
 * This software is released under the MIT License.
 * https://opensource.org/licenses/MIT
 */

#include "console/console.h"
#include "server/server.h"

void cmdExit(const consolecmdexec_t *exec) {
  CloseWindow();
}

void cmdServe(const consolecmdexec_t *exec) {
  serverStart(3030);
}

void cmdClose(const consolecmdexec_t *exec) {
  serverStop();
}

int main(void) {
  consoleInit();
  serverInit();

  consoleRegCmd("exit", cmdExit);
  consoleRegCmd("serve", cmdServe);
  consoleRegCmd("close", cmdClose);

  InitWindow(1280, 720, DUSK_NAME);

  while(!WindowShouldClose()) {
    consoleUpdate();

    BeginDrawing();
    ClearBackground(RAYWHITE);

    consoleDraw();

    EndDrawing();
  }

  CloseWindow();
  serverDispose();
  
  return EXIT_SUCCESS;
}